@@ -24,16 +24,19 @@ from ._craic import Craic
 from ._midas import MidasStressStrain
 from ._nsidat import NorthStarImageData
 from ._fei_tiff import FeiTiff
-from ._hyperspy import GenericHyperSpy
+# hyperspy removed for now.  Email sent to Andrew Sharits on 10/28/21 to see
+# if it is still of interest.
+# from ._hyperspy import GenericHyperSpy
 
 
 PARSERS = {
     'Ayasdi': Ayasdi,
+    'CenterStreet': CenterStreet,
     'Craic': Craic,
     'MidasStressStrain': MidasStressStrain,
     'NorthStarImageData': NorthStarImageData,
     'FeiTiff': FeiTiff,
-    'GenericHyperSpy': GenericHyperSpy,
+    # 'GenericHyperSpy': GenericHyperSpy,
 }
 
 
